@@ -1,4 +1,5 @@
 use super::cpu::CPU;
+use super::power::LidState;
 use std::fmt::Display;
 use termion::{color, style};
 
@@ -10,6 +11,14 @@ pub fn print_freq(f: i32, raw: bool) {
     }
 }
 
+pub fn print_power(lid: LidState, bat: i8, plugged: bool, raw: bool) {
+    if raw {
+        println!("{} {} {}", lid, bat, plugged);
+    } else {
+        println!("Lid: {} Battery: {} Plugged: {}", lid, bat, plugged);
+    }
+}
+
 pub fn print_turbo(t: bool, raw: bool) {
     if raw {
         println!("{}", t);
@@ -31,11 +40,10 @@ fn print_vec<T: Display>(t: Vec<T>, raw: bool) {
             println!("{}", x);
         }
     } else {
-        print!("[ ");
         for x in t {
-            print!("\"{}\" ", x);
+            print!("{} ", x);
         }
-        print!("]");
+        print!("\n")
     }
 }
 
@@ -43,10 +51,16 @@ pub fn print_available_governors(available_governors: Vec<String>, raw: bool) {
     print_vec(available_governors, raw);
 }
 
-pub fn print_cpus(cpus: Vec<CPU>, name: String) {
-    println!("Name:{}", name);
-    for x in cpus {
-        println!("{} is currently @ {} MHz", x.name, x.cur_freq / 1000);
+pub fn print_cpus(cpus: Vec<CPU>, name: String, raw: bool) {
+    if raw {
+        for x in cpus {
+            println!("{} {}", x.name, x.cur_freq);
+        }
+    } else {
+        println!("Name:{}", name);
+        for x in cpus {
+            println!("{} is currently @ {} MHz", x.name, x.cur_freq / 1000);
+        }
     }
 }
 
