@@ -1,7 +1,7 @@
 use daemon::{daemon_init, Checker};
 use display::{
     print_available_governors, print_cpu_governors, print_cpu_speeds, print_cpu_temp, print_cpus,
-    print_freq, print_turbo,
+    print_freq, print_power, print_turbo,
 };
 use error::Error;
 use power::{read_battery_charge, read_lid_state, read_power_source};
@@ -24,7 +24,10 @@ pub mod system;
 enum GetType {
     /// Get the power
     #[structopt(name = "power")]
-    Power,
+    Power {
+        #[structopt(short, long)]
+        raw: bool,
+    },
 
     /// The overall frequency of your cpu
     #[structopt(name = "freq")]
@@ -49,30 +52,42 @@ enum GetType {
 
     /// The names of the core
     #[structopt(name = "cpus")]
-    CPUS,
+    CPUS {
+        #[structopt(short, long)]
+        raw: bool,
+    },
 
     /// The speed of the individual cores
-    #[structopt(name = "cpu-speeds")]
+    #[structopt(name = "speeds")]
     Speeds {
         #[structopt(short, long)]
         raw: bool,
     },
 
     /// The temperature of the individual cores
-    #[structopt(name = "cpu-temp")]
+    #[structopt(name = "temp")]
     Temp {
         #[structopt(short, long)]
         raw: bool,
     },
 
     /// The governors of the individual cores
-    #[structopt(name = "cpu-govs")]
+    #[structopt(name = "govs")]
     Govs {
         #[structopt(short, long)]
         raw: bool,
     },
 }
 
+#[derive(StructOpt)]
+enum SetType {
+    #[structopt(name = "gov")]
+    Gov {
+        #[structopt()]
+        value: String,
+    },
+}
+
 #[derive(StructOpt)]
 #[structopt(
     name = "autoclockspeed",
@@ -87,6 +102,12 @@ enum Command {
         get: GetType,
     },
 
+    #[structopt(name = "set")]
+    Set {
+        #[structopt(subcommand)]
+        set: SetType,
+    },
+
     /// Run the daemon, this checks and edit your cpu's speed
     #[structopt(name = "run")]
     Run {
@@ -109,17 +130,20 @@ enum Command {
 }
 
 fn main() {
+    let mut main_daemon: daemon::Daemon;
+
     match Command::from_args() {
+        // Everything starting with "get"
         Command::Get { get } => match get {
             GetType::Freq { raw } => match check_cpu_freq() {
                 Ok(f) => print_freq(f, raw),
                 Err(_) => eprintln!("Faild to get cpu frequency"),
             },
-            GetType::Power {} => match read_lid_state() {
-                Ok(f) => match read_battery_charge() {
-                    Ok(c) => match read_power_source() {
-                        Ok(p) => {
-                            println!("Lid: {} Bat: {} Plugged in: {}", f, c, p)
+            GetType::Power { raw } => match read_lid_state() {
+                Ok(lid) => match read_battery_charge() {
+                    Ok(bat) => match read_power_source() {
+                        Ok(plugged) => {
+                            print_power(lid, bat, plugged, raw);
                         }
                         Err(_) => eprintln!("Faild to get read power source"),
                     },
@@ -135,9 +159,9 @@ fn main() {
                 Ok(available_governors) => print_available_governors(available_governors, raw),
                 Err(_) => println!("Failed to get available governors"),
             },
-            GetType::CPUS {} => match list_cpus() {
+            GetType::CPUS { raw } => match list_cpus() {
                 Ok(cpus) => match check_cpu_name() {
-                    Ok(name) => print_cpus(cpus, name),
+                    Ok(name) => print_cpus(cpus, name, raw),
                     Err(_) => println!("Failed get list of cpus"),
                 },
                 Err(_) => println!("Failed get list of cpus"),
@@ -155,15 +179,32 @@ fn main() {
                 Err(_) => println!("Failed to get list of cpu governors"),
             },
         },
+
+        // Everything starting with "set"
+        Command::Set { set } => match set {
+            SetType::Gov { value } => match daemon_init(true, 0, false) {
+                Ok(mut d) => match d.set_govs(value.clone()) {
+                    Ok(_) => {},
+                    Err(e) => eprint!("Could not set gov, {:?}", e),
+                },
+                Err(_) => eprint!("Could not run daemon in edit mode"),
+            },
+        },
+
+        // Run command
         Command::Run { quiet, delay } => match daemon_init(!quiet, delay, true) {
-            Ok(mut d) => {
-                d.run().unwrap_err();
+            Ok(d) => {
+                main_daemon = d;
+                main_daemon.run().unwrap_err();
             }
             Err(_) => eprint!("Could not run daemon in edit mode"),
         },
+
+        // Monitor command
         Command::Monitor { delay } => match daemon_init(true, delay, false) {
-            Ok(mut d) => {
-                d.run().unwrap_err();
+            Ok(d) => {
+                main_daemon = d;
+                main_daemon.run().unwrap_err();
             }
             Err(_) => eprint!("Could not run daemon in monitor mode"),
         },
